%if 0%{?fedora} > 12
%global with_python3 1
%else
%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print (get_python_lib())")}
%endif

%global         pkgname Django

# Tests requiring Internet connections are disabled by default
# pass --with internet to run them (e.g. when doing a local rebuild
# for sanity checks before committing)
%bcond_with internet

# one higher than the last Django release, to account for
# dist tags
%global         obs_ver 1.5.5-3

Name:           python-django
Version:        1.6.5
Release:        2%{?dist}
Summary:        A high-level Python Web framework

Group:          Development/Languages
License:        BSD
URL:            http://www.djangoproject.com/
Source0:        http://pypi.python.org/packages/source/D/Django/Django-%{version}.tar.gz

Patch0:         python-django-1.6-py3-admin-completion

BuildArch:      noarch
# Note: No longer required in development version > 0.95
# BuildRequires:  python-setuptools
BuildRequires:  python2-devel
# required for docs
BuildRequires:  python-sphinx

%if 0%{?with_python3}
BuildRequires:  python3-devel
%endif
Requires:       %{name}-bash-completion = %{version}-%{release}

# allow users to use django with lowercase d
Provides:       django = %{version}-%{release}
Provides:       %{pkgname} = %{version}-%{release}
Obsoletes:      %{pkgname} < %{obs_ver}

#
Obsoletes:      Django14

%description
Django is a high-level Python Web framework that encourages rapid
development and a clean, pragmatic design. It focuses on automating as
much as possible and adhering to the DRY (Don't Repeat Yourself)
principle.

%package doc
Summary:        Documentation for Django
Group:          Documentation
Requires:       %{name} = %{version}-%{release}

Provides:       django-docs = %{version}-%{release}
Provides:       %{pkgname}-docs = %{version}-%{release}
Obsoletes:      %{pkgname}-docs < %{obs_ver}

%description doc
This package contains the documentation for the Django high-level
Python Web framework.

%package bash-completion
Summary:        bash completion files for Django


%description bash-completion
This package contains the bash completion files form Django high-level
Python Web framework.

%if 0%{?with_python3}
%package -n python3-django-doc
Summary:        Documentation for Django
Group:          Documentation
Requires:       python3-django = %{version}-%{release}

%description -n python3-django-doc
This package contains the documentation for the Django high-level
Python Web framework.

%package -n python3-django
Summary:        A high-level Python Web framework
Group:          Development/Languages

Requires:       python3
Requires:       %{name}-bash-completion = %{version}-%{release}

%description -n python3-django
Django is a high-level Python Web framework that encourages rapid
development and a clean, pragmatic design. It focuses on automating as
much as possible and adhering to the DRY (Don't Repeat Yourself)
principle.
%endif

%prep
%setup -q -n %{pkgname}-%{version}

%patch0

# empty files
for f in \
    django/contrib/staticfiles/models.py \
    django/contrib/webdesign/models.py \
    django/contrib/humanize/models.py \
; do
  echo "# just a comment" > $f
done
echo "<!-- nothing -->" > django/contrib/flatpages/tests/templates/registration/login.html

%if 0%{?with_python3}
cp -a . %{py3dir}
%endif


%build
%{__python} setup.py build

%if 0%{?with_python3}
pushd %{py3dir}
%{__python3} setup.py build
popd
%endif # with_python3


%install
# must do install of python 3 subpackage first, so that we don't
# overwrite django-admin script with the python 3 version
%if 0%{?with_python3}
pushd %{py3dir}
%{__python3} setup.py install --skip-build --root %{buildroot}
mv %{buildroot}%{_bindir}/django-admin.py %{buildroot}%{_bindir}/python3-django-admin
popd
%endif # with_python3

%{__python} setup.py install --skip-build --root %{buildroot}

%if 0%{?rhel} == 6
# Handling locale files
# This is adapted from the %%find_lang macro, which cannot be directly
# used since Django locale files are not located in %%{_datadir}
#
# The rest of the packaging guideline still apply -- do not list
# locale files by hand!
(cd $RPM_BUILD_ROOT && find . -name 'django*.mo') | %{__sed} -e 's|^.||' |
%{__sed} -e \
   's:\(.*/locale/\)\([^/_]\+\)\(.*\.mo$\):%lang(\2) \1\2\3:' \
       >> django.lang
%else
%find_lang django
%find_lang djangojs
# append djangojs.lang to django.lang
cat djangojs.lang >> django.lang
%endif

%if 0%{?with_python3}
# When creating Python3 package, separate lang to Python 2 and Python 3 files
grep python3 django.lang > python3-django.lang
grep python2 django.lang > python2-django.lang
mv {python2-,}django.lang
%endif # with_python3

# build documentation
(cd docs && mkdir djangohtml && mkdir -p _build/{doctrees,html} && make html)


# install man pages
mkdir -p %{buildroot}%{_mandir}/man1/
cp -p docs/man/* %{buildroot}%{_mandir}/man1/
%if 0%{?with_python3}
cp -a %{buildroot}%{_mandir}/man1/django-admin.1 %{buildroot}%{_mandir}/man1/python3-django-admin.1
cp -a %{buildroot}%{_mandir}/man1/daily_cleanup.1 %{buildroot}%{_mandir}/man1/python3-daily_cleanup.1
cp -a %{buildroot}%{_mandir}/man1/gather_profile_stats.1 %{buildroot}%{_mandir}/man1/python3-gather_profile_stats.1
%endif # with_python3

# install bash completion script
mkdir -p %{buildroot}%{_sysconfdir}/bash_completion.d/
install -m 0644 -p extras/django_bash_completion \
   %{buildroot}%{_sysconfdir}/bash_completion.d/

# Fix items in %%{_bindir}
mv %{buildroot}%{_bindir}/django-admin.py %{buildroot}%{_bindir}/django-admin

# remove .po files
find $RPM_BUILD_ROOT -name "*.po" | xargs rm -f

%check
export PYTHONPATH=$(pwd)
export LANG=en_US.utf8
cd tests
./runtests.py --settings=test_sqlite --verbosity=2

%if 0%{?with_python3}
pushd %{py3dir}
export PYTHONPATH=%{py3dir}
cd tests
%{__python3} runtests.py --settings=test_sqlite --verbosity=2
popd
%endif # with_python3


%files -f django.lang 
%doc AUTHORS LICENSE README.rst
# manual pages are owned by both python2 and python3 packages
%{_mandir}/man1/*
# except the symlink with python3 prefix
%if 0%{?with_python3}
%exclude %{_mandir}/man1/python3-*
%endif # with_python3
%{_bindir}/django-admin
%attr(0755,root,root) %{python_sitelib}/django/bin/*-messages.py*
%attr(0755,root,root) %{python_sitelib}/django/bin/daily_cleanup.py*
%attr(0755,root,root) %{python_sitelib}/django/bin/django-admin.py*
%attr(0755,root,root) %{python_sitelib}/django/bin/django-2to3.py*
%dir %{python_sitelib}/django/bin/profiling/
%attr(0755,root,root) %{python_sitelib}/django/bin/profiling/gather_profile_stats.py
# Include everything but the locale data ...
%dir %{python_sitelib}/django
%dir %{python_sitelib}/django/bin
%{python_sitelib}/django/bin/profiling/__init__.py*
%{python_sitelib}/django/bin/profiling/gather_profile_stats.py?
%{python_sitelib}/django/db/
%{python_sitelib}/django/*.py*
%{python_sitelib}/django/shortcuts/
%{python_sitelib}/django/utils/
%{python_sitelib}/django/dispatch/
%{python_sitelib}/django/template/
%{python_sitelib}/django/views/
%dir %{python_sitelib}/django/conf/
%dir %{python_sitelib}/django/conf/locale/
%dir %{python_sitelib}/django/conf/locale/??/
%dir %{python_sitelib}/django/conf/locale/??_*/
%dir %{python_sitelib}/django/conf/locale/*/LC_MESSAGES
%dir %{python_sitelib}/django/contrib/
%{python_sitelib}/django/contrib/*.py*
%dir %{python_sitelib}/django/contrib/admin/
%dir %{python_sitelib}/django/contrib/admin/locale
%dir %{python_sitelib}/django/contrib/admin/locale/??/
%dir %{python_sitelib}/django/contrib/admin/locale/??_*/
%dir %{python_sitelib}/django/contrib/admin/locale/*/LC_MESSAGES
%{python_sitelib}/django/contrib/admin/*.py*
%dir %{python_sitelib}/django/contrib/admin/bin/
%attr(0755,root,root) %{python_sitelib}/django/contrib/admin/bin/compress.py
%{python_sitelib}/django/contrib/admin/bin/compress.py?
%{python_sitelib}/django/contrib/admin/views/
%{python_sitelib}/django/contrib/admin/static/
%{python_sitelib}/django/contrib/admin/templatetags/
%{python_sitelib}/django/contrib/admin/templates/
%dir %{python_sitelib}/django/contrib/admindocs/
%dir %{python_sitelib}/django/contrib/admindocs/locale/
%dir %{python_sitelib}/django/contrib/admindocs/locale/??/
%dir %{python_sitelib}/django/contrib/admindocs/locale/??_*/
%dir %{python_sitelib}/django/contrib/admindocs/locale/*/LC_MESSAGES
%{python_sitelib}/django/contrib/admindocs/*.py*
%{python_sitelib}/django/contrib/admindocs/templates/
%{python_sitelib}/django/contrib/admindocs/tests/
%dir %{python_sitelib}/django/contrib/auth/
%dir %{python_sitelib}/django/contrib/auth/locale/
%dir %{python_sitelib}/django/contrib/auth/locale/??/
%dir %{python_sitelib}/django/contrib/auth/locale/??_*/
%dir %{python_sitelib}/django/contrib/auth/locale/*/LC_MESSAGES
%{python_sitelib}/django/contrib/auth/*.py*
%{python_sitelib}/django/contrib/auth/fixtures/
%{python_sitelib}/django/contrib/auth/handlers/
%{python_sitelib}/django/contrib/auth/management/
%{python_sitelib}/django/contrib/auth/templates/
%{python_sitelib}/django/contrib/auth/tests/
%dir %{python_sitelib}/django/contrib/comments/
%dir %{python_sitelib}/django/contrib/comments/locale/
%dir %{python_sitelib}/django/contrib/comments/locale/??/
%dir %{python_sitelib}/django/contrib/comments/locale/??_*/
%dir %{python_sitelib}/django/contrib/comments/locale/*/LC_MESSAGES
%{python_sitelib}/django/contrib/comments/*.py*
%{python_sitelib}/django/contrib/comments/views
%{python_sitelib}/django/contrib/comments/templatetags
%{python_sitelib}/django/contrib/comments/templates
%dir %{python_sitelib}/django/contrib/contenttypes/
%dir %{python_sitelib}/django/contrib/contenttypes/locale
%dir %{python_sitelib}/django/contrib/contenttypes/locale/??/
%dir %{python_sitelib}/django/contrib/contenttypes/locale/??_*/
%dir %{python_sitelib}/django/contrib/contenttypes/locale/*/LC_MESSAGES
%{python_sitelib}/django/contrib/contenttypes/*.py*
%dir %{python_sitelib}/django/contrib/flatpages/
%dir %{python_sitelib}/django/contrib/flatpages/locale/
%dir %{python_sitelib}/django/contrib/flatpages/locale/??/
%dir %{python_sitelib}/django/contrib/flatpages/locale/??_*/
%dir %{python_sitelib}/django/contrib/flatpages/locale/*/LC_MESSAGES
%{python_sitelib}/django/contrib/flatpages/*.py*
%{python_sitelib}/django/contrib/flatpages/fixtures/
%{python_sitelib}/django/contrib/flatpages/templatetags
%{python_sitelib}/django/contrib/flatpages/tests
%dir %{python_sitelib}/django/contrib/formtools/
%dir %{python_sitelib}/django/contrib/formtools/locale/
%dir %{python_sitelib}/django/contrib/formtools/locale/??/
%dir %{python_sitelib}/django/contrib/formtools/locale/??_*/
%dir %{python_sitelib}/django/contrib/formtools/locale/*/LC_MESSAGES
%{python_sitelib}/django/contrib/formtools/*.py*
%{python_sitelib}/django/contrib/formtools/templates/
%{python_sitelib}/django/contrib/formtools/tests/
%{python_sitelib}/django/contrib/formtools/wizard/
%dir %{python_sitelib}/django/contrib/gis/
%dir %{python_sitelib}/django/contrib/gis/locale/
%dir %{python_sitelib}/django/contrib/gis/locale/??/
%dir %{python_sitelib}/django/contrib/gis/locale/??_*/
%dir %{python_sitelib}/django/contrib/gis/locale/*/LC_MESSAGES
%{python_sitelib}/django/contrib/gis/*.py*
%{python_sitelib}/django/contrib/gis/geoip/
%dir %{python_sitelib}/django/contrib/humanize/
%dir %{python_sitelib}/django/contrib/humanize/locale/
%dir %{python_sitelib}/django/contrib/humanize/locale/??/
%dir %{python_sitelib}/django/contrib/humanize/locale/??_*/
%dir %{python_sitelib}/django/contrib/humanize/locale/*/LC_MESSAGES
%{python_sitelib}/django/contrib/humanize/templatetags/
%{python_sitelib}/django/contrib/humanize/*.py*
%dir %{python_sitelib}/django/contrib/messages/
%dir %{python_sitelib}/django/contrib/messages/locale
%dir %{python_sitelib}/django/contrib/messages/locale/??/
%dir %{python_sitelib}/django/contrib/messages/locale/??_*/
%dir %{python_sitelib}/django/contrib/messages/locale/*/LC_MESSAGES
%{python_sitelib}/django/contrib/messages/*.py*
%{python_sitelib}/django/contrib/messages/tests
%dir %{python_sitelib}/django/contrib/redirects
%dir %{python_sitelib}/django/contrib/redirects/locale
%dir %{python_sitelib}/django/contrib/redirects/locale/??/
%dir %{python_sitelib}/django/contrib/redirects/locale/??_*/
%dir %{python_sitelib}/django/contrib/redirects/locale/*/LC_MESSAGES
%{python_sitelib}/django/contrib/redirects/*.py*
%dir %{python_sitelib}/django/contrib/sessions/
%dir %{python_sitelib}/django/contrib/sessions/locale/
%dir %{python_sitelib}/django/contrib/sessions/locale/??/
%dir %{python_sitelib}/django/contrib/sessions/locale/??_*/
%dir %{python_sitelib}/django/contrib/sessions/locale/*/LC_MESSAGES
%{python_sitelib}/django/contrib/sessions/management/
%{python_sitelib}/django/contrib/sessions/*.py*
%{python_sitelib}/django/contrib/sitemaps/
%dir %{python_sitelib}/django/contrib/sites/
%dir %{python_sitelib}/django/contrib/sites/locale/
%dir %{python_sitelib}/django/contrib/sites/locale/??/
%dir %{python_sitelib}/django/contrib/sites/locale/??_*/
%dir %{python_sitelib}/django/contrib/sites/locale/*/LC_MESSAGES
%{python_sitelib}/django/contrib/sites/*.py*
%{python_sitelib}/django/contrib/staticfiles/
%{python_sitelib}/django/contrib/syndication/
%{python_sitelib}/django/contrib/webdesign/
%{python_sitelib}/django/contrib/gis/admin/
%{python_sitelib}/django/contrib/gis/db/
%{python_sitelib}/django/contrib/gis/forms/
%{python_sitelib}/django/contrib/gis/gdal/
%{python_sitelib}/django/contrib/gis/geometry/
%{python_sitelib}/django/contrib/gis/geos/
%{python_sitelib}/django/contrib/gis/management/
%{python_sitelib}/django/contrib/gis/maps/
%{python_sitelib}/django/contrib/gis/sitemaps/
%{python_sitelib}/django/contrib/gis/static/gis/js/OLMapWidget.js
%{python_sitelib}/django/contrib/gis/templates/
%{python_sitelib}/django/contrib/gis/tests/
%{python_sitelib}/django/contrib/gis/utils/
%{python_sitelib}/django/contrib/messages/storage/
%{python_sitelib}/django/contrib/sessions/backends/
%{python_sitelib}/django/forms/
%{python_sitelib}/django/templatetags/ 
%{python_sitelib}/django/core/
%{python_sitelib}/django/http/
%{python_sitelib}/django/middleware/
%{python_sitelib}/django/test/
%{python_sitelib}/django/conf/*.py*
%{python_sitelib}/django/conf/project_template/
%{python_sitelib}/django/conf/app_template/
%{python_sitelib}/django/conf/urls/
%{python_sitelib}/django/conf/locale/*/*.py*
%{python_sitelib}/django/conf/locale/*.py*

%{python_sitelib}/*.egg-info

%files doc
%doc docs/_build/html/*

%files bash-completion
%dir %{_sysconfdir}/bash_completion.d/
%config(noreplace) %{_sysconfdir}/bash_completion.d/django_bash_completion

%if 0%{?with_python3}
%files -n python3-django-doc
%doc docs/_build/html/*

%files -n python3-django -f python3-django.lang
%doc AUTHORS LICENSE README.rst
%{_bindir}/python3-django-admin
# as said before, manpages are owned by both python2 and python3 packages
%exclude %{_mandir}/man1/django-admin.1*
%exclude %{_mandir}/man1/daily_cleanup.1.*
%exclude %{_mandir}/man1/gather_profile_stats.1.*
%{_mandir}/man1/python3-daily_cleanup.1.*
%{_mandir}/man1/python3-django-admin.1.*
%{_mandir}/man1/python3-gather_profile_stats.1.*
%attr(0755,root,root) %{python3_sitelib}/django/bin/*-messages.py*
%attr(0755,root,root) %{python3_sitelib}/django/bin/daily_cleanup.py*
%attr(0755,root,root) %{python3_sitelib}/django/bin/django-admin.py*
%attr(0755,root,root) %{python3_sitelib}/django/bin/django-2to3.py*
%dir %{python3_sitelib}/django/bin/profiling/
%attr(0755,root,root) %{python3_sitelib}/django/bin/profiling/gather_profile_stats.py
# Include everything but the locale data ...
%dir %{python3_sitelib}/django
%dir %{python3_sitelib}/django/bin
%{python3_sitelib}/django/bin/profiling/__init__.py*
%{python3_sitelib}/django/db/
%{python3_sitelib}/django/*.py*
%{python3_sitelib}/django/shortcuts/
%{python3_sitelib}/django/utils/
%{python3_sitelib}/django/dispatch/
%{python3_sitelib}/django/template/
%{python3_sitelib}/django/views/
%dir %{python3_sitelib}/django/conf/
%dir %{python3_sitelib}/django/conf/locale/
%dir %{python3_sitelib}/django/conf/locale/??/
%dir %{python3_sitelib}/django/conf/locale/??_*/
%dir %{python3_sitelib}/django/conf/locale/*/LC_MESSAGES
%dir %{python3_sitelib}/django/contrib/
%{python3_sitelib}/django/contrib/*.py*
%dir %{python3_sitelib}/django/contrib/admin/
%dir %{python3_sitelib}/django/contrib/admin/locale
%dir %{python3_sitelib}/django/contrib/admin/locale/??/
%dir %{python3_sitelib}/django/contrib/admin/locale/??_*/
%dir %{python3_sitelib}/django/contrib/admin/locale/*/LC_MESSAGES
%{python3_sitelib}/django/contrib/admin/*.py*
%dir %{python3_sitelib}/django/contrib/admin/bin/
%attr(0755,root,root) %{python3_sitelib}/django/contrib/admin/bin/compress.py
%{python3_sitelib}/django/contrib/admin/views/
%{python3_sitelib}/django/contrib/admin/static/
%{python3_sitelib}/django/contrib/admin/templatetags/
%{python3_sitelib}/django/contrib/admin/templates/
%dir %{python3_sitelib}/django/contrib/admindocs/
%dir %{python3_sitelib}/django/contrib/admindocs/locale/
%dir %{python3_sitelib}/django/contrib/admindocs/locale/??/
%dir %{python3_sitelib}/django/contrib/admindocs/locale/??_*/
%dir %{python3_sitelib}/django/contrib/admindocs/locale/*/LC_MESSAGES
%{python3_sitelib}/django/contrib/admindocs/*.py*
%{python3_sitelib}/django/contrib/admindocs/templates/
%{python3_sitelib}/django/contrib/admindocs/tests/
%dir %{python3_sitelib}/django/contrib/auth/
%dir %{python3_sitelib}/django/contrib/auth/locale/
%dir %{python3_sitelib}/django/contrib/auth/locale/??/
%dir %{python3_sitelib}/django/contrib/auth/locale/??_*/
%dir %{python3_sitelib}/django/contrib/auth/locale/*/LC_MESSAGES
%{python3_sitelib}/django/contrib/auth/*.py*
%{python3_sitelib}/django/contrib/auth/fixtures/
%{python3_sitelib}/django/contrib/auth/handlers/
%{python3_sitelib}/django/contrib/auth/management/
%{python3_sitelib}/django/contrib/auth/templates/
%{python3_sitelib}/django/contrib/auth/tests/
%dir %{python3_sitelib}/django/contrib/comments/
%dir %{python3_sitelib}/django/contrib/comments/locale/
%dir %{python3_sitelib}/django/contrib/comments/locale/??/
%dir %{python3_sitelib}/django/contrib/comments/locale/??_*/
%dir %{python3_sitelib}/django/contrib/comments/locale/*/LC_MESSAGES
%{python3_sitelib}/django/contrib/comments/*.py*
%{python3_sitelib}/django/contrib/comments/views
%{python3_sitelib}/django/contrib/comments/templatetags
%{python3_sitelib}/django/contrib/comments/templates
%dir %{python3_sitelib}/django/contrib/contenttypes/
%dir %{python3_sitelib}/django/contrib/contenttypes/locale
%dir %{python3_sitelib}/django/contrib/contenttypes/locale/??/
%dir %{python3_sitelib}/django/contrib/contenttypes/locale/??_*/
%dir %{python3_sitelib}/django/contrib/contenttypes/locale/*/LC_MESSAGES
%{python3_sitelib}/django/contrib/contenttypes/*.py*
%dir %{python3_sitelib}/django/contrib/flatpages/
%dir %{python3_sitelib}/django/contrib/flatpages/locale/
%dir %{python3_sitelib}/django/contrib/flatpages/locale/??/
%dir %{python3_sitelib}/django/contrib/flatpages/locale/??_*/
%dir %{python3_sitelib}/django/contrib/flatpages/locale/*/LC_MESSAGES
%{python3_sitelib}/django/contrib/flatpages/*.py*
%{python3_sitelib}/django/contrib/flatpages/fixtures/
%{python3_sitelib}/django/contrib/flatpages/templatetags
%{python3_sitelib}/django/contrib/flatpages/tests
%dir %{python3_sitelib}/django/contrib/formtools/
%dir %{python3_sitelib}/django/contrib/formtools/locale/
%dir %{python3_sitelib}/django/contrib/formtools/locale/??/
%dir %{python3_sitelib}/django/contrib/formtools/locale/??_*/
%dir %{python3_sitelib}/django/contrib/formtools/locale/*/LC_MESSAGES
%{python3_sitelib}/django/contrib/formtools/*.py*
%{python3_sitelib}/django/contrib/formtools/templates/
%{python3_sitelib}/django/contrib/formtools/tests/
%{python3_sitelib}/django/contrib/formtools/wizard/
%dir %{python3_sitelib}/django/contrib/gis/
%dir %{python3_sitelib}/django/contrib/gis/locale/
%dir %{python3_sitelib}/django/contrib/gis/locale/??/
%dir %{python3_sitelib}/django/contrib/gis/locale/??_*/
%dir %{python3_sitelib}/django/contrib/gis/locale/*/LC_MESSAGES
%{python3_sitelib}/django/contrib/gis/*.py*
%{python3_sitelib}/django/contrib/gis/geoip/
%dir %{python3_sitelib}/django/contrib/humanize/
%dir %{python3_sitelib}/django/contrib/humanize/locale/
%dir %{python3_sitelib}/django/contrib/humanize/locale/??/
%dir %{python3_sitelib}/django/contrib/humanize/locale/??_*/
%dir %{python3_sitelib}/django/contrib/humanize/locale/*/LC_MESSAGES
%{python3_sitelib}/django/contrib/humanize/templatetags/
%{python3_sitelib}/django/contrib/humanize/*.py*
%dir %{python3_sitelib}/django/contrib/messages/
%dir %{python3_sitelib}/django/contrib/messages/locale
%dir %{python3_sitelib}/django/contrib/messages/locale/??/
%dir %{python3_sitelib}/django/contrib/messages/locale/??_*/
%dir %{python3_sitelib}/django/contrib/messages/locale/*/LC_MESSAGES
%{python3_sitelib}/django/contrib/messages/*.py*
%{python3_sitelib}/django/contrib/messages/tests
%dir %{python3_sitelib}/django/contrib/redirects
%dir %{python3_sitelib}/django/contrib/redirects/locale
%dir %{python3_sitelib}/django/contrib/redirects/locale/??/
%dir %{python3_sitelib}/django/contrib/redirects/locale/??_*/
%dir %{python3_sitelib}/django/contrib/redirects/locale/*/LC_MESSAGES
%{python3_sitelib}/django/contrib/redirects/*.py*
%dir %{python3_sitelib}/django/contrib/sessions/
%dir %{python3_sitelib}/django/contrib/sessions/locale/
%dir %{python3_sitelib}/django/contrib/sessions/locale/??/
%dir %{python3_sitelib}/django/contrib/sessions/locale/??_*/
%dir %{python3_sitelib}/django/contrib/sessions/locale/*/LC_MESSAGES
%{python3_sitelib}/django/contrib/sessions/management/
%{python3_sitelib}/django/contrib/sessions/*.py*
%{python3_sitelib}/django/contrib/sitemaps/
%dir %{python3_sitelib}/django/contrib/sites/
%dir %{python3_sitelib}/django/contrib/sites/locale/
%dir %{python3_sitelib}/django/contrib/sites/locale/??/
%dir %{python3_sitelib}/django/contrib/sites/locale/??_*/
%dir %{python3_sitelib}/django/contrib/sites/locale/*/LC_MESSAGES
%{python3_sitelib}/django/contrib/sites/*.py*
%{python3_sitelib}/django/contrib/staticfiles/
%{python3_sitelib}/django/contrib/syndication/
%{python3_sitelib}/django/contrib/webdesign/
%{python3_sitelib}/django/contrib/gis/admin/
%{python3_sitelib}/django/contrib/gis/db/
%{python3_sitelib}/django/contrib/gis/forms/
%{python3_sitelib}/django/contrib/gis/gdal/
%{python3_sitelib}/django/contrib/gis/geometry/
%{python3_sitelib}/django/contrib/gis/geos/
%{python3_sitelib}/django/contrib/gis/management/
%{python3_sitelib}/django/contrib/gis/maps/
%{python3_sitelib}/django/contrib/gis/sitemaps/
%{python3_sitelib}/django/contrib/gis/static/gis/js/OLMapWidget.js
%{python3_sitelib}/django/contrib/gis/templates/
%{python3_sitelib}/django/contrib/gis/tests/
%{python3_sitelib}/django/contrib/gis/utils/
%{python3_sitelib}/django/contrib/messages/storage/
%{python3_sitelib}/django/contrib/sessions/backends/
%{python3_sitelib}/django/forms/
%{python3_sitelib}/django/templatetags/ 
%{python3_sitelib}/django/core/
%{python3_sitelib}/django/http/
%{python3_sitelib}/django/middleware/
%{python3_sitelib}/django/test/
%{python3_sitelib}/django/conf/*.py*
%{python3_sitelib}/django/conf/project_template/
%{python3_sitelib}/django/conf/app_template/
%{python3_sitelib}/django/conf/urls/
%{python3_sitelib}/django/conf/locale/*/*.py*
%{python3_sitelib}/django/conf/locale/*.py*
%{python3_sitelib}/%{pkgname}-%{version}-py3.?.egg-info
%{python3_sitelib}/django/__pycache__
%{python3_sitelib}/django/bin/__pycache__
%{python3_sitelib}/django/bin/profiling/__pycache__
%{python3_sitelib}/django/conf/__pycache__
%{python3_sitelib}/django/conf/locale/*/__pycache__
%{python3_sitelib}/django/contrib/__pycache__
%{python3_sitelib}/django/contrib/admin/__pycache__
%{python3_sitelib}/django/contrib/admin/bin/__pycache__
%{python3_sitelib}/django/contrib/admindocs/__pycache__
%{python3_sitelib}/django/contrib/auth/__pycache__
%{python3_sitelib}/django/contrib/comments/__pycache__
%{python3_sitelib}/django/contrib/contenttypes/__pycache__
%{python3_sitelib}/django/contrib/flatpages/__pycache__
%{python3_sitelib}/django/contrib/formtools/__pycache__
%{python3_sitelib}/django/contrib/gis/__pycache__
%{python3_sitelib}/django/contrib/humanize/__pycache__
%{python3_sitelib}/django/contrib/messages/__pycache__
%{python3_sitelib}/django/contrib/redirects/__pycache__
%{python3_sitelib}/django/contrib/sessions/__pycache__
%{python3_sitelib}/django/contrib/sites/__pycache__
%endif


%changelog
* Mon Jul 14 2014 Matthias Runge <mrunge@redhat.com> - 1.6.5-2
- obsolete Django14 (rhbz#1114291)

* Fri May 16 2014 Matthias Runge <mrunge@redhat.com> - 1.6.5-1
- update to 1.6.5 CVE-2014-1418, CVE-2014-3730 (rhbz#1097935)

* Mon May 12 2014 Matthias Runge <mrunge@redhat.com> - 1.6.4-2
- don't hardcode python3.3

* Wed May 07 2014 Matthias Runge <mrunge@redhat.com> - 1.6.4-1
- update to 1.6.4 fix a potential regression in reverse()

* Tue Apr 22 2014 Matthias Runge <mrunge@redhat.com> - 1.6.3-1
- update to 1.6.3 fixing CVE-2014-0473 and CVE-2014-0474

* Thu Mar 27 2014 Matthias Runge <mrunge@redhat.com> - 1.6.2-2
- remove simplejson requirement
- make bash-completion a sub-package, both main packages can require

* Thu Feb 13 2014 Matthias Runge <mrunge@redhat.com> - 1.6.2-1
- update to 1.6.2 (rhbz#1027766)
- bash completion for python3-django-admin (rhbz#1035987)

* Mon Jan 27 2014 Matthias Runge <mrunge@redhat.com> - 1.5.4-3
- python-simplejson is not a hard requirement any more

* Thu Dec 19 2013 Dennis Gilmore <dennis@ausil.us> - 1.5.4-2
- disable python3 on epel7

* Sun Nov 24 2013 Matěj Cepl <mcepl@redhat.com> - 1.6-1
- update to 1.6 (rhbz#1027766)

* Tue Oct 29 2013 Matthias Runge <mrunge@redhat.com> - 1.5.5-2
- fix obsoletes

* Mon Oct 28 2013 Matthias Runge <mrunge@redhat.com> - 1.5.5-1
- update to 1.5.5 (rhbz#1023407)
>>>>>>> master

* Mon Sep 16 2013 Matthias Runge <mrunge@redhat.com> - 1.5.4-1
- fix CVE-2013-1443 (DoS via large passwords), fixes rhbz#1008281

* Wed Sep 11 2013 Matthias Runge <mrunge@redhat.com> - 1.5.3-1
- fix CVE-2013-4315 (ssi issue), fixes rhbz 1004969

* Tue Aug 20 2013 Matthias Runge <mrunge@redhat.com> - 1.5.2-2
- increase obsoletes to 1.4.6-2

* Wed Aug 14 2013 Matthias Runge <mrunge@redhat.com> - 1.5.2-1
- security related update

* Mon Aug 05 2013 Matthias Runge <mrunge@redhat.com> - 1.5.1-3
- rebuild to fix build issues during mass rebuild.

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.5.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Apr 02 2013 Matthias Runge <mrunge@redhat.com> - 1.5.1-1
- update to Django-1.5.1 (rhbz#929413)

* Wed Mar 27 2013 Miro Hrončok <mhroncok@redhat.com> - 1.5-3
- separated lang files for Python 2 and 3
- list %%files in Python 3 subpackage more precisely to not include locale files
- added %%doc to Python 3 subpackage
- removed trailing slash after %%{buildroot} to avoid double slash
- fixed bogus dates in %%changelog
- made %%check verbose, so it is not so boring to watch them run
- created python3 doc package
- created python3- prefixed symlink to manpage
- comment added about shared content - manpages

* Wed Mar 27 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 1.5-2
- Make the python3 subpackage install first, so that django-admin
  doesn't get overwritten.
- Don't own %%{python3_sitelib} itself, but only its contents.

* Wed Feb 27 2013 Matthias Runge <mrunge@redhat.com> - 1.5-1
- update to Django-1.5

* Thu Feb 21 2013 Matthias Runge <mrunge@redhat.com> - 1.4.5-2
- update to latest stable upstream version
- fix minor packaging issues introduced upstream

* Wed Feb 20 2013 Matthias Runge <mrunge@redhat.com> - 1.4.4-1
- update to 1.4.4 (rhbz #913024)
- Data leakage via admin history log CVE-2013-0305 (rhbz #913041)
- Formset denial-of-service CVE-2013-0306 (rhbz #913042)

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jan 24 2013 Matthias Runge <mrunge@redhat.com> - 1.4.3-2
- also obsolete version 1.4.3-1

* Sun Jan 13 2013 Matthias Runge <mrunge@redhat.com> - 1.4.3-2
- own directories (rhbz#894533)

* Tue Dec 11 2012 Matthias Runge <mrunge@redhat.com> - 1.4.3-1
- security update to upstream version 1.4.3
  https://www.djangoproject.com/weblog/2012/dec/10/security/

* Fri Nov 16 2012 Bohuslav Kabrda <bkabrda@redhat.com> - 1.4.2-2
- Bump obsoletes version, since there is still Django-1.4.2-1 out there.
- Fix a provide that should allow users to use "django" instead of "Django".

* Thu Oct 18 2012 Matthias Runge <mrunge@redhat.com> - 1.4.2-1
- security update to upstream version 1.4.2-1
  https://www.djangoproject.com/weblog/2012/oct/17/security/

* Thu Sep 20 2012 Matthias Runge <mrunge@redhat.com> - 1.4.1-2
- fix provides: Django

* Wed Aug 01 2012 Matthias Runge <mrunge@matthias-runge.de> - 1.4.1-1
- update to 1.4.1 fixing CVE-2012-3442, CVE-2012-3443, and CVE-2012-3444

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed May 30 2012 Matthias Runge <mrunge@matthias-runge.de> - 1.4-4
- fix for FTBFS using python 2.7.3 (thanks to  M.Cepl)

* Tue Mar 27 2012 Matthias Runge <mrunge@matthias-runge.de> - 1.4-3
- revert change from 1.4-2
- really fix simplejson-import

* Tue Mar 27 2012 Matthias Runge <mrunge@matthias-runge.de> - 1.4-2
- fix simplejson-import (port from django-1.3-package)

* Sun Mar 25 2012 Michel Salim <salimma@fedoraproject.org> - 1.4-1
- Update to 1.4

* Mon Mar 19 2012 Matthias Runge <mrunge@matthias-runge.de> - 1.3.1-9
- spec cleanup

* Sat Mar 17 2012 Matthias Runge <mrunge@matthias-runge.de> - 1.3.1-8
- patch tests to work on koji (no internet connection)

* Sat Mar 10 2012 Michel Salim <salimma@fedoraproject.org> - 1.3.1-7
- Enable tests
- Now obsoletes (last Django release+1)
- Mark Bash completion script as a configuration file

* Fri Mar 09 2012 Matthias Runge <mrunge@matthias-runge.de> - 1.3.1-6
- add additional provides django = %%{version}-%%{release}

* Wed Mar 07 2012 Matthias Runge <mrunge@matthias-runge.de> - 1.3.1-5
- rename package to python-django

* Thu Jan 12 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Oct 12 2011 Michel Salim <salimma@fedoraproject.org> - 1.3.1-3
- Package bash completion script

* Sat Sep 10 2011 Michel Salim <salimma@fedoraproject.org> - 1.3.1-2
- Switch to the 'html' doc builder, for easier navigation without a web server

* Sat Sep 10 2011 Michel Salim <salimma@fedoraproject.org> - 1.3.1-1
- Update to 1.3.1
- Remove workaround for non-functional -doc generation
- Deduplicate file listing

* Wed Mar 30 2011 Steve Milner <me@stevemilner.org> - 1.3-2
- Fix for BZ#693865

* Wed Mar 30 2011 Steve Milner <me@stevemilner.org> - 1.3-1
- Fix for es_MX upstream bug
- Update for upstream release

* Wed Feb  9 2011 Steve Milner <me@stevemilner.org> - 1.2.5-1
- Fix for CVE-2011-0697

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Jan  3 2011 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.2.4-1
- Update for multiple security issues (see http://www.djangoproject.com/weblog/2010/dec/22/security/)

* Sat Oct  9 2010 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.2.3-3
- Now build docs for F12+
- Added Django-remove-djangodocs-ext.patch

* Sat Oct  9 2010 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.2.3-2
- Moved to dirhtml for documentation generation

* Mon Sep 13 2010 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.2.3-1
- Update for http://www.djangoproject.com/weblog/2010/sep/10/123/

* Thu Sep  9 2010 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.2.2-1
- Update for CVE-2010-3082 (see http://www.djangoproject.com/weblog/2010/sep/08/security-release/)
- Removed Django-hash-compat-13310.patch as it is already included in this release

* Wed Jul 21 2010 David Malcolm <dmalcolm@redhat.com> - 1.2.1-6
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Tue Jun  8 2010 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.2.1-5
- Added http://code.djangoproject.com/changeset/13310?format=diff&new=13310 per BZ#601212

* Thu Jun  3 2010 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.2.1-4
- Include egg in >= rhel6

* Thu Jun  3 2010 Michel Salim <salimma@fedoraproject.org> - 1.2.1-3
- Use generated %%{name}.lang instead of including each locale file by hand
- Temporarily make main package provide -doc on Rawhide, to fix upgrade path
  until upstream documentation builds with Sphinx 1.0

* Thu May 27 2010 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.2.1-2
- Allow for building docs in F13 as it's only F14 freaking out

* Tue May 25 2010 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.2.1-1
- Update for new release.
- Added lang files per BZ#584866.
- Changed perms on %%{python_sitelib}/django/contrib/admin/media/js/compress.py
- Lots of explicit files listed in %%files in order to reduce duplicate file listings
- Docs are not built on F-13 for now

* Wed Oct 21 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.1.1-2
- Removed po files per BZ#529188.

* Fri Oct  9 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.1.1-1
- Update to fix http://www.djangoproject.com/weblog/2009/oct/09/security/
- Django-ignore-pyo-bz-495046.patch no longer needed.

* Wed Aug 26 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.1-4
- EL-4 shouldn't get the sphinx docs.

* Wed Aug 26 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.1-3
- ghosting admin py* is now FC9 and under.

* Thu Aug  6 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.1-2
- Applied Daniel Mach's patch from bz#516016.

* Sat Aug  1 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.1-1
- Update for Django 1.1 release.
- Moved /usr/bin/django-admin.py to /usr/bin/django-admin
- sed macro is now being used
- Patch for bz#495046 applied.

* Wed Jul 29 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.0.3-6
- Attempted combined spec for F12/11/10 and EL5

* Wed Jul 29 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.0.3-4
- Older builds must ghost django-admin.py[c,o]

* Wed Jul 29 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.0.3-3
- Bump for tag issue.

* Wed Jul 29 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.0.3-2
- Fix changelog.

* Wed Jul 29 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.0.3-1
- Upgrade for http://www.djangoproject.com/weblog/2009/jul/28/security/

* Thu Mar 12 2009 Michel Salim <salimma@fedoraproject.org> - 1.0.2-3
- Build HTML documentation (bug #484070)
- No longer excluding *.py? in bindir, F11's Python does not optimizes these

* Mon Feb 23 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sun Dec 14 2008 Michel Salim <salimma@fedoraproject.org> - 1.0.2-1
- Update to 1.0.2

* Sat Nov  1 2008 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.0.1-0.1.beta1
- Update to 1.0.1_beta_1

* Sat Sep  6 2008 Michel Salim <salimma@fedoraproject.org> - 1.0-1
- Update to final 1.0 release

* Tue Sep  2 2008 Michel Salim <salimma@fedoraproject.org> - 1.0-0.1.rc1%{?dist}
- CSRF security update: bz#460966

* Wed Aug 27 2008 Michel Salim <salimma@fedoraproject.org> - 1.0-0.1.beta2
- Update to 1.0 beta2

* Sat Aug 23 2008 Michel Salim <salimma@fedoraproject.org> - 1.0-0.1.beta1
- Update to 1.0 beta1

* Mon May 19 2008 Michel Salim <salimma@fedoraproject.org> - 0.96.2-1
- XSS security update: CVE-2008-2302 (bz# 442757-60)

* Sat Apr  5 2008 Michel Salim <salimma@fedoraproject.org> - 0.96.1-2
- Package .egg-info file on Fedora >= 9

* Thu Nov  1 2007 Michel Salim <michel.sylvan@gmail.com> 0.96.1-1
- i18n security update: CVE-2007-5712, bz#357051

* Sat Mar 24 2007 Michel Salim <michel.salim@gmail.com> - 0.96-1
- New upstream version

* Sun Jan 21 2007 Michel Salim <michel.salim@gmail.com> - 0.95.1-1
- Upstream security updates:
  http://www.djangoproject.com/weblog/2007/jan/21/0951/

* Sun Nov 12 2006 Michel Salim <michel.salim@gmail.com> - 0.95-1
- Initial package
